#include <Keyboard_RAW.h>

/*
 * Arduino code for a USB version of the Chorder
 * Hacked from the Feather verson to use with a Pro Mini
 * I was tired of VUSB problems with my origional spiffchorder
 * 
 * Based on
 * Arduino code for a Bluetooth version of the Chorder.
 * @author: clc@clcworld.net
 * additional code by: priestdo@budgardr.org
 * This version tested on/with the Adafruit Feather 32u4 Bluefruit LE
 *
 * It is a new arduino based chorder inspired by the SpiffChorder 
 * which can be found at http://symlink.dk/projects/spiffchorder/ 
 */

#include <Arduino.h>
//#include <SPI.h>
//#if not defined (_VARIANT_ARDUINO_DUE_X_)
//#include <SoftwareSerial.h>
//#endif

#include "KeyCodes.h"
#include "ChordMappings.h"

// A small helper
void error(const __FlashStringHelper*err) {
  Serial.println(err);
  while (1);
}

// moved to KeyCodes.h

// moved to ChordMappings.h


class Button {
  byte _pin;  // The button's I/O pin, as an Arduino pin number.
  
public:
  Button(byte pin) : _pin(pin) {
    pinMode(pin, INPUT_PULLUP);      // Make pin an input and activate pullup.
  }
  
  bool isDown() const {
    // TODO: this assumes we're using analog pins!
    //return analogRead(_pin) < 0x100;
    return (digitalRead(_pin) == LOW);
  }
};


// Pin numbers for the keyboard switches, using the Arduino numbering.
// On a Pro Micro, 8765432 is nice because the next pin is gnd
static const Button switch_pins[7] = {
  Button(8),  // Pinky
  Button(7),  // Ring
  Button(6),  // Middle
  Button(5),  // Index
  Button(4),  // Near Thumb
  Button(3),  // Center Thumb
  Button(2),  // Far Thumb
};

void setup(void)
{

  Serial.begin(115200);
  Serial.println("Arduino Pro Mini USB HID Chorder");

  //Initalize the 32U4 Keyboard
  Keyboard_RAW.begin();
}


enum State {
  PRESSING,
  RELEASING,
};

State state = RELEASING;
byte lastKeyState = 0;

enum Mode {
  ALPHA,
  NUMSYM,
  FUNCTION
};

bool isCapsLocked = false;
bool isNumsymLocked = false;
keymap_t modKeys = 0x00;

Mode mode = ALPHA;

//void send(char* character) {
////  Uart.print(character);
//}

void sendKey(byte keyState){
  keymap_t theKey;  
  // Determine the key based on the current mode's keymap
  if (mode == ALPHA) {
    theKey = keymap_default[keyState];
  } else if (mode == NUMSYM) {
    theKey = keymap_numsym[keyState];
  } else {
    theKey = keymap_function[keyState];
  }

  switch (theKey)  {
  // Handle mode switching - return immediately after the mode has changed
  // Handle basic mode switching
  case MODE_NUM:
    if (mode == NUMSYM) {
      mode = ALPHA;
    } else {
      mode = NUMSYM;
    }
    return;
  case MODE_FUNC:
    if (mode == FUNCTION) {
      mode = ALPHA;
    } else {
      mode = FUNCTION;
    }
    return;
  case MODE_RESET:
    mode = ALPHA;
    modKeys = 0x00;
    isCapsLocked = false;
    isNumsymLocked = false;
    return;
  case MODE_MRESET:
    mode = ALPHA;
    modKeys = 0x00;
    isCapsLocked = false;
    isNumsymLocked = false;       

    return;
  // Handle mode locks
  case ENUMKEY_cpslck:
    if (isCapsLocked){
      isCapsLocked = false;
      modKeys = 0x00;
    } else {
      isCapsLocked = true;
      modKeys = 0x02;
    }
    return;
  case MODE_NUMLCK:
    if (isNumsymLocked){
      isNumsymLocked = false;
      mode = ALPHA;
    } else {
      isNumsymLocked = true;
      mode = NUMSYM;
    }
    return;
  // Handle modifier keys toggling
  case MOD_LCTRL:
    modKeys = modKeys ^ 0x01;
    return;
  case MOD_LSHIFT:
    modKeys = modKeys ^ 0x02;
    return;
  case MOD_LALT:
    modKeys = modKeys ^ 0x04;
    return;
  case MOD_LGUI:
    modKeys = modKeys ^ 0x08;
    return;
  case MOD_RCTRL:
    modKeys = modKeys ^ 0x10;
    return;
  case MOD_RSHIFT:
    modKeys = modKeys ^ 0x20;
    return;
  case MOD_RALT:
    modKeys = modKeys ^ 0x40;
    return;
  case MOD_RGUI:
    modKeys = modKeys ^ 0x80;
    return;
  // Handle special keys
  case MULTI_NumShift:
    if (mode == NUMSYM) {
      mode = ALPHA;
    } else {
      mode = NUMSYM;
    }
    modKeys = modKeys ^ 0x02;
    return;
  case MULTI_CtlAlt:
    modKeys = modKeys ^ 0x01;
    modKeys = modKeys ^ 0x04;
    return;
  /* Everything after this sends actual keys to the system; break rather than
     return since we want to reset the modifiers after these keys are sent. */
  case MACRO_000:
    sendRawKey(0x00, 0x27);
    sendRawKey(0x00, 0x27);
    sendRawKey(0x00, 0x27);
    break;
  case MACRO_00:
    sendRawKey(0x00, 0x27);
    sendRawKey(0x00, 0x27);
    break;
  case MACRO_quotes:
    sendRawKey(0x02, 0x34);
    sendRawKey(0x02, 0x34);
    sendRawKey(0x00, 0x50);
    break;
  case MACRO_parens:
    sendRawKey(0x02, 0x26);
    sendRawKey(0x02, 0x27);
    sendRawKey(0x00, 0x50);
    break;
  case MACRO_dollar:
    sendRawKey(0x02, 0x21);
    break;
  case MACRO_percent:
    sendRawKey(0x02, 0x22);
    break;
  case MACRO_ampersand:
    sendRawKey(0x02, 0x24);
    break;
  case MACRO_asterisk:
    sendRawKey(0x02, 0x25);
    break;
  case MACRO_question:
    sendRawKey(0x02, 0x38);
    break;
  case MACRO_plus:
    sendRawKey(0x02, 0x2E);
    break;
  case MACRO_openparen:
    sendRawKey(0x02, 0x26);
    break;
  case MACRO_closeparen:
    sendRawKey(0x02, 0x27);
    break;
  case MACRO_opencurly:
    sendRawKey(0x02, 0x2F);
    break;
  case MACRO_closecurly:
    sendRawKey(0x02, 0x30);
    break;
  // Handle Android specific keys
  case ANDROID_search:
    sendRawKey(0x04, 0x2C);
    break;
  case ANDROID_home:
    sendRawKey(0x04, 0x29);
    break;
  case ANDROID_menu:
    sendRawKey(0x10, 0x29);
    break;
  case ANDROID_back:
    sendRawKey(0x00, 0x29);
    break;
  case ANDROID_dpadcenter:
    sendRawKey(0x00, 0x5D);
    break;
//  case MEDIA_playpause:
//    sendControlKey("PLAYPAUSE");
//    break;
//  case MEDIA_stop:
//    sendControlKey("MEDIASTOP");
//    break;
//  case MEDIA_next:
//    sendControlKey("MEDIANEXT");
//    break;
//  case MEDIA_previous:
//    sendControlKey("MEDIAPREVIOUS");
//    break;
//  case MEDIA_volup:
//    sendControlKey("VOLUME+,500");
//    break;
//  case MEDIA_voldn:
//    sendControlKey("VOLUME-,500");
//    break;
  // Send the key
  default:
    sendRawKey(modKeys, theKey);
    break;
  }

  modKeys = 0x00;
  mode = ALPHA;
  // Reset the modKeys and mode based on locks
  if (isCapsLocked){
    modKeys = 0x02;
  }
  if (isNumsymLocked){
    mode = NUMSYM;
  }
}

void sendRawKey(char modKey, char rawKey){
  //I should really just not make it inherit from Print, so I can use write(m,c)
//    Serial.print(modKey,HEX);
//    Serial.print(',');
//    Serial.println(rawKey,HEX);
    Keyboard_RAW.write(modKey,rawKey);
}

//void sendControlKey(String cntrlName){
//  //Would require nonstandard hacks to USBAPI.h
//  // See: http://stefanjones.ca/blog/arduino-leonardo-remote-multimedia-keys/
//  // note: for Volume +/- and the few other keys that take a time to hold, simply add it into the string
//  // for example:
//  //    sendControlKey("VOLUME+,500")
//  // will send Volume up and hold it for half a second
//  ble.print("AT+BLEHIDCONTROLKEY=");
//  ble.println(cntrlName);  
//}  
byte previousStableReading = 0;
byte currentStableReading = 0;
long lastDebounceTime = 0;  // the last time the output pin was toggled
long debounceDelay = 10;    // the debounce time; increase if the output flickers

void processReading(){
    switch (state) {
    case PRESSING:
      if (previousStableReading & ~currentStableReading) {
        state = RELEASING;
        sendKey(previousStableReading);
      } 
      break;

    case RELEASING:
      if (currentStableReading & ~previousStableReading) {
        state = PRESSING;
      }
      break;
    }
}

void loop() {
  // Build the current key state.
  byte keyState = 0, mask = 1;
  for (int i = 0; i < 7; i++) {
    if (switch_pins[i].isDown()) keyState |= mask;
    mask <<= 1;
  }

  if (lastKeyState != keyState) {
    lastDebounceTime = millis();
  }

  if ((millis() - lastDebounceTime) > debounceDelay) {
    // whatever the reading is at, it's been there for longer
    // than the debounce delay, so take it as the actual current state:
    currentStableReading = keyState;
  }

  if (previousStableReading != currentStableReading) {
    processReading();
    previousStableReading = currentStableReading;
  }

  lastKeyState = keyState;
}

